library global;

import 'package:flutter/material.dart';

export 'package:android_path_provider/android_path_provider.dart';
export 'package:device_info_plus/device_info_plus.dart';
export 'package:flutter_downloader/flutter_downloader.dart';
export 'package:flutter_svg/flutter_svg.dart';
export 'package:fluttertoast/fluttertoast.dart';
export 'package:http/http.dart';
export 'package:intl/intl.dart';
export 'package:path_provider/path_provider.dart';
export 'package:permission_handler/permission_handler.dart';

export './src/GColors.dart';
export './src/GDateFormats.dart';
export './src/GHttpReqs.dart';
export './src/GPageTransition.dart';
export './src/GRefreshingWidget.dart';
export './src/GRegExpMatchers.dart';
export './src/GTextInputFormatters.dart';
export './src/GTexts.dart';
export './src/GUtils.dart';
export './src/GValidators.dart';

class Global {
  static bool _initialized = false;
  static late Color _themeColor;
  static late TextStyle _defaultEnabledStyle;
  static late TextStyle _defaultDisabledStyle;
  static late TextStyle _defaultLabelStyle;
  static late TextStyle _defaultFloatingLabelStyle;
  static late GlobalKey<NavigatorState> _navigatorKey;

  /// Initializes the plugin. This must be called before any other method.
  static initialize({
    required Color themeColor,
    required TextStyle defaultEnabledStyle,
    required TextStyle defaultDisabledStyle,
    required TextStyle defaultLabelStyle,
    required TextStyle defaultFloatingLabelStyle,
    required GlobalKey<NavigatorState> navigatorKey,
  }) {
    assert(
      !_initialized,
      'Plugin \'global\' has already been initialized',
    );
    _themeColor = themeColor;
    _defaultEnabledStyle = defaultEnabledStyle;
    _defaultDisabledStyle = defaultDisabledStyle;
    _defaultLabelStyle = defaultLabelStyle;
    _defaultFloatingLabelStyle = defaultFloatingLabelStyle;
    _navigatorKey = navigatorKey;
    _initialized = true;
  }

  static Color get themeColor => _themeColor;

  static TextStyle get defaultEnabledStyle => _defaultEnabledStyle;

  static TextStyle get defaultDisabledStyle => _defaultDisabledStyle;

  static TextStyle get defaultLabelStyle => _defaultLabelStyle;

  static TextStyle get defaultFloatingLabelStyle => _defaultFloatingLabelStyle;

  static GlobalKey<NavigatorState> get navigatorKey => _navigatorKey;
}
